@@ -11,16 +11,20 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 from ibm_botocore import xform_name
+from ibm_botocore.docs.method import (
+    document_custom_method,
+    document_model_driven_method,
+)
 from ibm_botocore.model import OperationModel
 from ibm_botocore.utils import get_service_module_name
-from ibm_botocore.docs.method import document_model_driven_method
-from ibm_botocore.docs.method import document_custom_method
 
 from ibm_boto3.docs.base import BaseDocumenter
 from ibm_boto3.docs.method import document_model_driven_resource_method
-from ibm_boto3.docs.utils import get_resource_ignore_params
-from ibm_boto3.docs.utils import get_resource_public_actions
-from ibm_boto3.docs.utils import add_resource_type_overview
+from ibm_boto3.docs.utils import (
+    add_resource_type_overview,
+    get_resource_ignore_params,
+    get_resource_public_actions,
+)
 
 
 class ActionDocumenter(BaseDocumenter):
@@ -30,7 +34,8 @@ class ActionDocumenter(BaseDocumenter):
         for modeled_action in modeled_actions_list:
             modeled_actions[modeled_action.name] = modeled_action
         resource_actions = get_resource_public_actions(
-            self._resource.__class__)
+            self._resource.__class__
+        )
         self.member_map['actions'] = sorted(resource_actions)
         add_resource_type_overview(
             section=section,
@@ -38,8 +43,10 @@ class ActionDocumenter(BaseDocumenter):
             description=(
                 'Actions call operations on resources.  They may '
                 'automatically handle the passing in of arguments set '
-                'from identifiers and some attributes.'),
-            intro_link='actions_intro')
+                'from identifiers and some attributes.'
+            ),
+            intro_link='actions_intro',
+        )
 
         for action_name in sorted(resource_actions):
             action_section = section.add_new_section(action_name)
@@ -50,7 +57,7 @@ class ActionDocumenter(BaseDocumenter):
                     resource_name=self._resource_name,
                     event_emitter=self._resource.meta.client.meta.events,
                     load_model=self._resource_model.load,
-                    service_model=self._service_model
+                    service_model=self._service_model,
                 )
             elif action_name in modeled_actions:
                 document_action(
@@ -62,11 +69,18 @@ class ActionDocumenter(BaseDocumenter):
                 )
             else:
                 document_custom_method(
-                    action_section, action_name, resource_actions[action_name])
+                    action_section, action_name, resource_actions[action_name]
+                )
 
 
-def document_action(section, resource_name, event_emitter, action_model,
-                    service_model, include_signature=True):
+def document_action(
+    section,
+    resource_name,
+    event_emitter,
+    action_model,
+    service_model,
+    include_signature=True,
+):
     """Documents a resource action
 
     :param section: The section to write to
@@ -83,7 +97,8 @@ def document_action(section, resource_name, event_emitter, action_model,
         It is useful for generating docstrings.
     """
     operation_model = service_model.operation_model(
-        action_model.request.operation)
+        action_model.request.operation
+    )
     ignore_params = get_resource_ignore_params(action_model.request.params)
 
     example_return_value = 'response'
@@ -92,23 +107,31 @@ def document_action(section, resource_name, event_emitter, action_model,
     example_resource_name = xform_name(resource_name)
     if service_model.service_name == resource_name:
         example_resource_name = resource_name
-    example_prefix = '%s = %s.%s' % (
-        example_return_value, example_resource_name, action_model.name)
+    example_prefix = '{} = {}.{}'.format(
+        example_return_value, example_resource_name, action_model.name
+    )
     document_model_driven_resource_method(
-        section=section, method_name=action_model.name,
+        section=section,
+        method_name=action_model.name,
         operation_model=operation_model,
         event_emitter=event_emitter,
         method_description=operation_model.documentation,
         example_prefix=example_prefix,
         exclude_input=ignore_params,
         resource_action_model=action_model,
-        include_signature=include_signature
+        include_signature=include_signature,
     )
 
 
-def document_load_reload_action(section, action_name, resource_name,
-                                event_emitter, load_model, service_model,
-                                include_signature=True):
+def document_load_reload_action(
+    section,
+    action_name,
+    resource_name,
+    event_emitter,
+    load_model,
+    service_model,
+    include_signature=True,
+):
     """Documents the resource load action
 
     :param section: The section to write to
@@ -127,22 +150,24 @@ def document_load_reload_action(section, action_name, resource_name,
         It is useful for generating docstrings.
     """
     description = (
-        'Calls  :py:meth:`%s.Client.%s` to update the attributes of the'
-        ' %s resource. Note that the load and reload methods are '
-        'the same method and can be used interchangeably.' % (
+        'Calls :py:meth:`{}.Client.{}` to update the attributes of the '
+        '{} resource. Note that the load and reload methods are '
+        'the same method and can be used interchangeably.'.format(
             get_service_module_name(service_model),
             xform_name(load_model.request.operation),
-            resource_name)
+            resource_name,
+        )
     )
     example_resource_name = xform_name(resource_name)
     if service_model.service_name == resource_name:
         example_resource_name = resource_name
-    example_prefix = '%s.%s' % (example_resource_name, action_name)
+    example_prefix = f'{example_resource_name}.{action_name}'
     document_model_driven_method(
-        section=section, method_name=action_name,
+        section=section,
+        method_name=action_name,
         operation_model=OperationModel({}, service_model),
         event_emitter=event_emitter,
         method_description=description,
         example_prefix=example_prefix,
-        include_signature=include_signature
+        include_signature=include_signature,
     )
